SigillinGenerator | unified-mandala - v1.0.0
Description: Documentation for unified-mandala

# Function SigillinGenerator

- SigillinGenerator(id, type, status, creator, schema_version?): Sigillin

- #### Parameters

  - id: string
  - type: "fallback-anchor" | "poetic-root" | "crep-trigger" | "session-memory" | "ethik-node"
  - status: "draft" | "reviewed" | "published"
  - creator: string
  - schema_version: string = '1.0.0'

  #### Returns Sigillin

  - Defined in packages/genesis-sigillin-core/SigillinGenerator.ts:10